diff mbox series

[v3,1/3] ata: ahci_brcm: Correct reset control API usage

Message ID 20200107183022.26224-2-f.fainelli@gmail.com
State New
Headers show
Series [v3,1/3] ata: ahci_brcm: Correct reset control API usage | expand

Commit Message

Florian Fainelli Jan. 7, 2020, 6:30 p.m. UTC
Philipp provided suggestions on using the
devm_reset_control_get_optional_*() API such that checks against a NULL
or error reset control resource could be eliminated. In the process,
make sure that we also grab the BCM7216 reset control line using the
shared semantics, since the "rescal" reset fits that model.

Suggested-by: Philipp Zabel <p.zabel@pengutronix.de>
Signed-off-by: Florian Fainelli <f.fainelli@gmail.com>
---
 drivers/ata/ahci_brcm.c | 32 +++++++++++++++++---------------
 1 file changed, 17 insertions(+), 15 deletions(-)
diff mbox series

Patch

diff --git a/drivers/ata/ahci_brcm.c b/drivers/ata/ahci_brcm.c
index 13ceca687104..718516fe6997 100644
--- a/drivers/ata/ahci_brcm.c
+++ b/drivers/ata/ahci_brcm.c
@@ -349,11 +349,10 @@  static int brcm_ahci_suspend(struct device *dev)
 	brcm_sata_phys_disable(priv);
 
 	ret = ahci_platform_suspend(dev);
+	if (ret)
+		return ret;
 
-	if (!IS_ERR_OR_NULL(priv->rcdev))
-		reset_control_assert(priv->rcdev);
-
-	return ret;
+	return reset_control_assert(priv->rcdev);
 }
 
 static int brcm_ahci_resume(struct device *dev)
@@ -363,8 +362,7 @@  static int brcm_ahci_resume(struct device *dev)
 	struct brcm_ahci_priv *priv = hpriv->plat_data;
 	int ret = 0;
 
-	if (!IS_ERR_OR_NULL(priv->rcdev))
-		ret = reset_control_deassert(priv->rcdev);
+	ret = reset_control_deassert(priv->rcdev);
 	if (ret)
 		return ret;
 
@@ -425,7 +423,6 @@  static int brcm_ahci_probe(struct platform_device *pdev)
 {
 	const struct of_device_id *of_id;
 	struct device *dev = &pdev->dev;
-	const char *reset_name = NULL;
 	struct brcm_ahci_priv *priv;
 	struct ahci_host_priv *hpriv;
 	struct resource *res;
@@ -447,15 +444,21 @@  static int brcm_ahci_probe(struct platform_device *pdev)
 	if (IS_ERR(priv->top_ctrl))
 		return PTR_ERR(priv->top_ctrl);
 
 	/* Reset is optional depending on platform and named differently */
 	if (priv->version == BRCM_SATA_BCM7216)
-		reset_name = "rescal";
+		priv->rcdev = devm_reset_control_get_optional_shared(dev,
+								     "rescal");
 	else
-		reset_name = "ahci";
+		priv->rcdev = devm_reset_control_get_optional_exclusive(dev,
+									"ahci");
+	if (IS_ERR(priv->rcdev))
+		return PTR_ERR(priv->rcdev);
 
-	priv->rcdev = devm_reset_control_get(&pdev->dev, reset_name);
-	if (!IS_ERR_OR_NULL(priv->rcdev))
-		reset_control_deassert(priv->rcdev);
+	ret = reset_control_deassert(priv->rcdev);
+	if (ret)
+		return ret;
 
 	hpriv = ahci_platform_get_resources(pdev, 0);
 	if (IS_ERR(hpriv)) {
@@ -519,8 +522,7 @@  static int brcm_ahci_probe(struct platform_device *pdev)
 out_disable_clks:
 	ahci_platform_disable_clks(hpriv);
 out_reset:
-	if (!IS_ERR_OR_NULL(priv->rcdev))
-		reset_control_assert(priv->rcdev);
+	reset_control_assert(priv->rcdev);
 	return ret;
 }
@@ -447,15 +444,21 @@  static int brcm_ahci_probe(struct platform_device *pdev)
 		return PTR_ERR(priv->top_ctrl);
 
-	/* Reset is optional depending on platform and named differently */
+	/* Reset is optional depending on platform and named differently
+	 * and of different kind (shared vs. exclusive)
+	 */
 	if (priv->version == BRCM_SATA_BCM7216)